%{?mingw_package_header}

%global pkgname openal-soft

# Disable qtgui by default for now
%bcond_with qtgui

Name:           mingw-%{pkgname}
Version:        1.21.0
Release:        %mkrel 1
Summary:        Open Audio Library
Group:          Development/Other
License:        LGPLv2+
URL:            https://www.openal-soft.org
Source0:        https://www.openal-soft.org/openal-releases/%{pkgname}-%{version}.tar.bz2
# Fixed in a different manner upstream
#Patch1:         openal-soft-1.18.2-fix-check_include_file-for-windows.patch

BuildArch:      noarch

BuildRequires:  cmake

# Win32 BRs
BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-headers
BuildRequires:  mingw32-SDL2
BuildRequires:  mingw32-SDL2_mixer
%if %{with qtgui}
BuildRequires:  mingw32-qt
BuildRequires:  mingw32-qt-tools
BuildRequires:  mingw32-qt-qmake
%endif

# Win64 BRs
BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-gcc-c++
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-headers
BuildRequires:  mingw64-SDL2
BuildRequires:  mingw64-SDL2_mixer
%if %{with qtgui}
BuildRequires:  mingw64-qt
BuildRequires:  mingw64-qt-tools
BuildRequires:  mingw64-qt-qmake
%endif

%description
OpenAL Soft is a cross-platform software implementation of the OpenAL 3D
audio API. It's built off of the open-sourced Windows version available
originally from the SVN repository at openal.org. OpenAL provides
capabilities for playing audio in a virtual 3d environment. Distance
attenuation, doppler shift, and directional sound emitters are among
the features handled by the API. More advanced effects, including air
absorption, low-pass filters, and reverb, are available through the
EFX extension. It also facilitates streaming audio, multi-channel buffers,
and audio capture.

# Win32
%package -n mingw32-%{pkgname}
Summary:        MinGW compiled OpenAL Soft library for Win32 target
Provides:       mingw32-openal = %{version}-%{release}

%description -n mingw32-%{pkgname}
OpenAL Soft is a cross-platform software implementation of the OpenAL 3D
audio API. It's built off of the open-sourced Windows version available
originally from the SVN repository at openal.org. OpenAL provides
capabilities for playing audio in a virtual 3d environment. Distance
attenuation, doppler shift, and directional sound emitters are among
the features handled by the API. More advanced effects, including air
absorption, low-pass filters, and reverb, are available through the
EFX extension. It also facilitates streaming audio, multi-channel buffers,
and audio capture.

This package provides the library for the Win32 target.

# Win64
%package -n mingw64-%{pkgname}
Summary:        MinGW compiled OpenAL Soft library for Win64 target
Provides:       mingw64-openal = %{version}-%{release}

%description -n mingw64-%{pkgname}
OpenAL Soft is a cross-platform software implementation of the OpenAL 3D
audio API. It's built off of the open-sourced Windows version available
originally from the SVN repository at openal.org. OpenAL provides
capabilities for playing audio in a virtual 3d environment. Distance
attenuation, doppler shift, and directional sound emitters are among
the features handled by the API. More advanced effects, including air
absorption, low-pass filters, and reverb, are available through the
EFX extension. It also facilitates streaming audio, multi-channel buffers,
and audio capture.

This package provides the library for the Win64 target.


%{?mingw_debug_package}


%prep
%autosetup -n %{pkgname}-%{version} -p1

%build
%mingw_cmake .

%mingw_make %{?_smp_mflags}

%install
%mingw_make install DESTDIR=%{buildroot}

find %{buildroot} -name '*.la' -exec rm -f {} ';'
install -Dpm644 alsoftrc.sample %{buildroot}%{mingw32_sysconfdir}/openal/alsoft.conf
install -Dpm644 alsoftrc.sample %{buildroot}%{mingw64_sysconfdir}/openal/alsoft.conf

%files -n mingw32-%{pkgname}
%license COPYING
%{mingw32_bindir}/OpenAL32.dll
%{mingw32_bindir}/alloopback.exe
%{mingw32_bindir}/alrecord.exe
%{mingw32_bindir}/altonegen.exe
%{mingw32_bindir}/openal-info.exe
%if %{with qtgui}
%{mingw32_bindir}/alsoft-config
%endif
%{mingw32_sysconfdir}/openal
%{mingw32_includedir}/AL
%{mingw32_libdir}/libOpenAL32.dll.a
%{mingw32_libdir}/cmake/OpenAL/
%{mingw32_libdir}/pkgconfig/openal.pc
%{mingw32_datadir}/openal

%files -n mingw64-%{pkgname}
%license COPYING
%{mingw64_bindir}/OpenAL32.dll
%{mingw64_bindir}/alloopback.exe
%{mingw64_bindir}/alrecord.exe
%{mingw64_bindir}/altonegen.exe
%{mingw64_bindir}/openal-info.exe
%if %{with qtgui}
%{mingw64_bindir}/alsoft-config
%endif
%{mingw64_sysconfdir}/openal
%{mingw64_includedir}/AL
%{mingw64_libdir}/libOpenAL32.dll.a
%{mingw64_libdir}/cmake/OpenAL/
%{mingw64_libdir}/pkgconfig/openal.pc
%{mingw64_datadir}/openal


%changelog
* Wed Dec 30 2020 akien <akien> 1.21.0-1.mga8
+ Revision: 1665698
- Version 1.21.0

* Mon Sep 28 2020 tv <tv> 1.18.2-3.mga8
+ Revision: 1630900
- rollback to working 1.18.2
- rebuild for new mingw stack
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ daviddavid <daviddavid>
- new version: 1.19.1
- rediff arm_neon-only-for-32bit patch

* Thu Sep 20 2018 umeabot <umeabot> 1.18.2-2.mga7
+ Revision: 1279927
- Mageia 7 Mass Rebuild

* Fri Jun 15 2018 daviddavid <daviddavid> 1.18.2-1.mga7
+ Revision: 1237138
- new version: 1.18.2

* Sat Aug 26 2017 akien <akien> 1.18.1-1.mga7
+ Revision: 1147990
- Version 1.18.1

* Mon Jul 17 2017 akien <akien> 1.18.0-1.mga7
+ Revision: 1124244
- Version 1.18.0

* Sat Nov 19 2016 akien <akien> 1.17.2-1.mga6
+ Revision: 1068351
- Adapt release and group to Mageia
- import mingw-openal-soft from the copr of ngompa

